@@ -16,7 +16,9 @@ from .sql import query_sql
     help="Print the code to markdown, in addition to running",
 )
 @argument("-o", "--output", type=str, help="A variable name to save the result as")
-@argument("-q", "--quiet", action="store_true", help="Whether to hide the result printout")
+@argument(
+    "-q", "--quiet", action="store_true", help="Whether to hide the result printout"
+)
 @register_cell_magic
 def sql(line, cell):
     # %%sql -m
@@ -45,4 +47,8 @@ def capture_parameters(line, cell):
     # We assume the last line is a tuple
     tup = [s.strip() for s in cell.strip().split("\n")[-1].split(",")]
 
-    print(json.dumps({identifier: shell.user_ns[identifier] for identifier in tup if identifier}))
+    print(
+        json.dumps(
+            {identifier: shell.user_ns[identifier] for identifier in tup if identifier}
+        )
+    )
