@@ -1,6 +1,5 @@
-from calitp_data.config import is_development
-from siuba.sql import LazyTbl
-from sqlalchemy.engine import Inspector
+from siuba.sql import LazyTbl  # type: ignore[import]
+from sqlalchemy.engine.reflection import Inspector
 
 from .sql import get_engine
 
@@ -110,13 +109,12 @@ class TableFactory:
                 </tr>
                 {table_body_html}
             </table>
-            """
+            """  # noqa: E221,E222
 
 
 tbls = AutoTable(
     get_engine(),
     lambda s: s,  # s.replace(".", "_"),
-    lambda s: "zzz_test_" not in s if not is_development() else True,
 )
 
 tbls._init()
